==> imp-3.2.2.tbz: www/horde/imp/config/servers.php <==
<?php
/*
 * $Horde: imp/config/servers.php.dist,v 1.16.2.8 2002/10/18 15:38:10 jan Exp $
 *
 * This file is where you specify what servers people using your
 * installation of IMP can log in to. There are a number of properties
 * that you can set for each server:
 *
 * name: This is the plaintext, english name that you want displayed
 * to people if you are using the drop down server list.
 *
 * server: The hostname of the mail server to connect to.
 *
 * protocol: One of 'imap/notls' (or only 'imap' if you have a
 * c-client version 2000c or older), 'pop3', 'imap/ssl', or
 * 'pop3/ssl'.  If it's pop3 you're going to be connecting to a POP3
 * mail server instead of IMAP (so make sure the port is correct - 110
 * by default), and all folder options will be automatically turned
 * off. The two ssl options will only work if you've compiled PHP
 * against an SSL-enabled version of c-client, used the
 * --with-imap-ssl flag compiling PHP, and you have a mail server
 * which supports SSL. The default ports are 993 for IMAP over SSL,
 * and 995 for POP3 over SSL.
 *
 * NOTE: If you are using a self-signed server certificate with with either
 * imap/ssl or pop3/ssl, you MUST add /novalidate-cert at the end of the
 * protocol string. So for imap, this would be "imap/ssl/novalidate-cert",
 * and for pop3 it would be "pop3/ssl/novalidate-cert". This is necessary to
 * tell c-client not to complain about the lack of a valid CA on the
 * certificate.
 *
 * port: The port that the mail (imap or pop) service this server runs
 * is on.
 *
 * folders: The folder path for the IMAP server. i.e. UW IMAP
 * generally looks to "Mail/" while Cyrus and Courier put folders
 * under "INBOX." (not the trailing dot. IMPORTANT: Use this only if
 * you want to restrict users to this subfolder. If you set this to
 * 'INBOX.' with Cyrus or Courier-IMAPd, then users will not be able
 * to use any shared folders - nothing outside of INBOX. will be
 * visible (except, of course, their INBOX itself). If you simply want
 * to mask out the INBOX. prefix (or another prefix) for presentation
 * purposes, use the 'namespace' attribute.  NOTE: If you use this
 * option, DO NOT SET NAMESPACE!
 *
 * namespace: This is where you put any paths that you want stripped
 * out for presentation purposes (i.e., you don't want your users to
 * have to know that their personal folders are actually subfolders of
 * their INBOX). A common value for this with Cyrus-style IMAP servers
 * is 'INBOX.'. NOTE: If you have shared folders, using this may
 * create confusion between shared folders and personal folders, if
 * users have folders with the same name as a shared folder.  NOTE: If
 * you use this option, DO NOT SET FOLDERS!
 *
 * maildomain: What to put after the @ when sending mail. i.e. if you
 * want all mail to look like "From: max@the-triumvirate.net" set
 * maildomain to "the-triumvirate.net". It is generally useful when
 * the imap host is different from the mail receiving host. This will
 * also be used to complete unqualified addresses in the compose
 * screen.
 *
 * smtphost: If specified, and $conf['mailer']['type'] is set to 'smtp',
 * IMP will use this host for outbound SMTP connections.  This value
 * overrides any existing $conf['mailer']['params']['host'] value at runtime.
 *
 * realm: What to append to usernames for preferences and Horde
 * authentication to prevent login clashes on virtual host setups.
 *
 * preferred is only useful if you want to use the same servers.php
 * file for different machines: if the Hostname of the IMP Machine is
 * identical to one of those in the preferred list, then the
 * corresponding option in the select box will include SELECTED,
 * i.e. it is selected per default. Otherwise the first entry in the
 * list is selected.
 *
 * Here are some example configurations:
 */

// Any entries whose key value ('foo' in $servers['foo']) begin with
// '_' (an underscore character) will be treated as prompts, and you
// won't be able to log in to them. The only property these entries
// need is 'name'. This lets you put labels in the list, like this
// example:
$servers['_prompt'] = array(
    'name' => _("Choose a mail server:")
);

$servers['imap'] = array(
    'name' => 'IMAP Server',
//  'server' => 'imap.gohan10.freebsd.org',
    'server' => 'localhost',
    'protocol' => 'imap/ssl/novalidate-cert',
    'port' => 993,
    'folders' => 'Mail/',
    'namespace' => '',
    'maildomain' => 'gohan10.freebsd.org',
//  'smtphost' => 'smtp.gohan10.freebsd.org',
    'smtphost' => 'localhost',
//  'realm' => 'gohan10.freebsd.org',
    'realm' => '',
    'preferred' => ''
);

$servers['cyrus'] = array(
    'name' => 'Cyrus IMAP Server',
    'server' => 'cyrus.gohan10.freebsd.org',
    'protocol' => 'imap/notls',
    'port' => 143,
    'folders' => '',
    'namespace' => 'INBOX.',
    'maildomain' => 'gohan10.freebsd.org',
    'realm' => 'gohan10.freebsd.org',
    'preferred' => ''
);

$servers['pop'] = array(
    'name' => 'POP3 Server',
    'server' => 'pop.gohan10.freebsd.org',
    'protocol' => 'pop3',
    'port' => 110,
    'folders' => '',
    'namespace' => '',
    'maildomain' => 'gohan10.freebsd.org',
    'realm' => 'gohan10.freebsd.org',
    'preferred' => ''
);

$servers['exchange'] = array(
    'name' => 'Exchange 5.5 server',
    'server' => 'exchange.gohan10.freebsd.org',
    'protocol' => 'imap',
    'port' => 143,
    'folders' => '',
    'namespace' => '',
    'maildomain' => 'gohan10.freebsd.org',
    'realm' => '',
    'preferred' => ''
);

==> imp-3.2.6.tbz: www/horde/imp/config/servers.php <==
<?php
/*
 * $Horde: imp/config/servers.php.dist,v 1.16.2.9 2004/05/30 09:35:13 jan Exp $
 *
 * This file is where you specify what servers people using your
 * installation of IMP can log in to. There are a number of properties
 * that you can set for each server:
 *
 * name: This is the plaintext, english name that you want displayed
 * to people if you are using the drop down server list.
 *
 * server: The hostname of the mail server to connect to.
 *
 * protocol: One of 'imap/notls' (or only 'imap' if you have a
 * c-client version 2000c or older), 'pop3', 'imap/ssl', or
 * 'pop3/ssl'.  If it's pop3 you're going to be connecting to a POP3
 * mail server instead of IMAP (so make sure the port is correct - 110
 * by default), and all folder options will be automatically turned
 * off. The two ssl options will only work if you've compiled PHP
 * against an SSL-enabled version of c-client, used the
 * --with-imap-ssl flag compiling PHP, and you have a mail server
 * which supports SSL. The default ports are 993 for IMAP over SSL,
 * and 995 for POP3 over SSL.
 *
 * NOTE: If you are using a self-signed server certificate with with either
 * imap/ssl or pop3/ssl, you MUST add /novalidate-cert at the end of the
 * protocol string. So for imap, this would be "imap/ssl/novalidate-cert",
 * and for pop3 it would be "pop3/ssl/novalidate-cert". This is necessary to
 * tell c-client not to complain about the lack of a valid CA on the
 * certificate.
 *
 * port: The port that the mail (imap or pop) service this server runs
 * is on.
 *
 * folders: The folder path for the IMAP server. i.e. UW IMAP
 * generally looks to "Mail/" while Cyrus and Courier put folders
 * under "INBOX." (note the trailing dot. IMPORTANT: Use this only if
 * you want to restrict users to this subfolder. If you set this to
 * 'INBOX.' with Cyrus or Courier-IMAPd, then users will not be able
 * to use any shared folders - nothing outside of INBOX. will be
 * visible (except, of course, their INBOX itself). If you simply want
 * to mask out the INBOX. prefix (or another prefix) for presentation
 * purposes, use the 'namespace' attribute.  NOTE: If you use this
 * option, DO NOT SET NAMESPACE!
 *
 * namespace: This is where you put any paths that you want stripped
 * out for presentation purposes (i.e., you don't want your users to
 * have to know that their personal folders are actually subfolders of
 * their INBOX). A common value for this with Cyrus-style IMAP servers
 * is 'INBOX.'. NOTE: If you have shared folders, using this may
 * create confusion between shared folders and personal folders, if
 * users have folders with the same name as a shared folder.  NOTE: If
 * you use this option, DO NOT SET FOLDERS!
 *
 * maildomain: What to put after the @ when sending mail. i.e. if you
 * want all mail to look like "From: max@the-triumvirate.net" set
 * maildomain to "the-triumvirate.net". It is generally useful when
 * the imap host is different from the mail receiving host. This will
 * also be used to complete unqualified addresses in the compose
 * screen.
 *
 * smtphost: If specified, and $conf['mailer']['type'] is set to 'smtp',
 * IMP will use this host for outbound SMTP connections.  This value
 * overrides any existing $conf['mailer']['params']['host'] value at runtime.
 *
 * realm: What to append to usernames for preferences and Horde
 * authentication to prevent login clashes on virtual host setups.
 *
 * preferred is only useful if you want to use the same servers.php
 * file for different machines: if the Hostname of the IMP Machine is
 * identical to one of those in the preferred list, then the
 * corresponding option in the select box will include SELECTED,
 * i.e. it is selected per default. Otherwise the first entry in the
 * list is selected.
 *
 * Here are some example configurations:
 */

// Any entries whose key value ('foo' in $servers['foo']) begin with
// '_' (an underscore character) will be treated as prompts, and you
// won't be able to log in to them. The only property these entries
// need is 'name'. This lets you put labels in the list, like this
// example:
$servers['_prompt'] = array(
    'name' => _("Choose a mail server:")
);

$servers['imap'] = array(
    'name' => 'IMAP Server',
//  'server' => 'imap.hammer01.freebsd.org',
    'server' => 'localhost',
    'protocol' => 'imap/ssl/novalidate-cert',
    'port' => 993,
    'folders' => 'Mail/',
    'namespace' => '',
    'maildomain' => 'hammer01.freebsd.org',
//  'smtphost' => 'smtp.hammer01.freebsd.org',
    'smtphost' => 'localhost',
//  'realm' => 'hammer01.freebsd.org',
    'realm' => '',
    'preferred' => ''
);

$servers['cyrus'] = array(
    'name' => 'Cyrus IMAP Server',
    'server' => 'cyrus.hammer01.freebsd.org',
    'protocol' => 'imap/notls',
    'port' => 143,
    'folders' => '',
    'namespace' => 'INBOX.',
    'maildomain' => 'hammer01.freebsd.org',
    'realm' => 'hammer01.freebsd.org',
    'preferred' => ''
);

$servers['pop'] = array(
    'name' => 'POP3 Server',
    'server' => 'pop.hammer01.freebsd.org',
    'protocol' => 'pop3',
    'port' => 110,
    'folders' => '',
    'namespace' => '',
    'maildomain' => 'hammer01.freebsd.org',
    'realm' => 'hammer01.freebsd.org',
    'preferred' => ''
);

$servers['exchange'] = array(
    'name' => 'Exchange 5.5 server',
    'server' => 'exchange.hammer01.freebsd.org',
    'protocol' => 'imap',
    'port' => 143,
    'folders' => '',
    'namespace' => '',
    'maildomain' => 'hammer01.freebsd.org',
    'realm' => '',
    'preferred' => ''
);
